import {
  JupyterFrontEnd,
  JupyterFrontEndPlugin
} from '@jupyterlab/application';
import { ILauncher } from '@jupyterlab/launcher';
import { LabIcon } from '@jupyterlab/ui-components';
import { MainAreaWidget } from '@jupyterlab/apputils';
import CateWidget from './widget';

/*
 CATE Logo
*/
import cateLogoSqStr from '../static/cate-logo-bw.svg';
const cateLogoIcon = new LabIcon({
  name: 'cate:logo',
  svgstr: cateLogoSqStr
});



/*
 * The command IDs used by the react-widget plugin.
 */
namespace CommandIDs {
  export const create = 'create-cate-widget';
}


/**
 * Initialization data for the jupyterlab-cate extension.
 */
const catePlugin: JupyterFrontEndPlugin<void> = {
  id: 'jupyterlab-cate:plugin',
  description: 'A JupyterLab extension for accessing CATE server',
  autoStart: true,
  optional: [ILauncher],
  activate: (app: JupyterFrontEnd,launcher: ILauncher) => {
    console.log('JupyterLab extension jupyterlab-cate is activated!');

	const { commands } = app;
    const command = CommandIDs.create;
    commands.addCommand(command, {
        caption: 'Connect to CATE Server',
        label: 'Connect to CATE Server',
        icon: args => (args['isPalette'] ? undefined : cateLogoIcon),
        execute: () => {
            const content = new CateWidget();
            const widget = new MainAreaWidget<CateWidget>({ content });
            widget.title.label = 'CATE';
            widget.title.icon = cateLogoIcon;
            app.shell.add(widget, 'main');
        }
    });

        if(launcher){
            launcher.add({command});
        }


  }
};

export default catePlugin;
